@@ -7,8 +7,8 @@ use Data::HTML::Element::Utils qw(check_data check_data_type);
 use Error::Pure qw(err);
 use List::Util 1.33 qw(none);
 use Mo qw(build default is);
-use Mo::utils qw(check_array check_bool check_required);
-use Mo::utils::CSS qw(check_css_class);
+use Mo::utils 0.06 qw(check_array check_bool check_required);
+use Mo::utils::CSS 0.02 qw(check_css_class);
 use Readonly;
 
 Readonly::Array our @DATA_TYPES => qw(plain tags);
@@ -20,7 +20,7 @@ Readonly::Array our @ENCTYPES => (
 Readonly::Array our @FORM_METHODS => qw(get post);
 Readonly::Array our @TYPES => qw(button reset submit);
 
-our $VERSION = 0.15;
+our $VERSION = 0.16;
 
 has autofocus => (
 	ro => 1,
@@ -560,6 +560,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.15
+0.16
 
 =cut
