@@ -7,7 +7,7 @@ use Data::HTML::Element::Utils qw(check_data check_data_type);
 use Error::Pure qw(err);
 use List::Util 1.33 qw(none);
 use Mo qw(build is);
-use Mo::utils::CSS qw(check_css_class);
+use Mo::utils::CSS 0.02 qw(check_css_class);
 use Readonly;
 
 Readonly::Array our @METHODS => qw(get post);
@@ -17,7 +17,7 @@ Readonly::Array our @ENCTYPES => (
 	'text/plain',
 );
 
-our $VERSION = 0.15;
+our $VERSION = 0.16;
 
 has action => (
 	is => 'ro',
@@ -358,6 +358,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.15
+0.16
 
 =cut
