@@ -5,10 +5,10 @@ use warnings;
 
 use Data::HTML::Element::Utils qw(check_data check_data_type);
 use Mo qw(build default is);
-use Mo::utils qw(check_bool check_number);
-use Mo::utils::CSS qw(check_css_class);
+use Mo::utils 0.26 qw(check_bool check_number);
+use Mo::utils::CSS 0.02 qw(check_css_class);
 
-our $VERSION = 0.15;
+our $VERSION = 0.16;
 
 has autofocus => (
 	is => 'ro',
