@@ -4,10 +4,10 @@ use strict;
 use warnings;
 
 use Mo qw(build is);
-use Mo::utils qw(check_bool check_number);
-use Mo::utils::CSS qw(check_css_class);
+use Mo::utils 0.26 qw(check_bool check_number);
+use Mo::utils::CSS 0.02 qw(check_css_class);
 
-our $VERSION = 0.15;
+our $VERSION = 0.16;
 
 has autofocus => (
 	is => 'ro',
@@ -408,6 +408,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.15
+0.16
 
 =cut
